const path = require('path');
const fs = require('fs');

/**
 * Find all files inside a dir, recursively.
 * @function getAllFiles
 * @param  {string} dir Dir path string.
 * @return {string[]} Array with all file names that are inside the directory.
 */
const getAllFiles = (dir, options) => {
  const fileExtensionExp = options.typescript ? /\.(js|ts)$/ : /\.js$/;
  return fs
    .readdirSync(dir)
    .reduce((files, file) => {
      const name = path.join(dir, file);
      const isDirectory = fs.statSync(name).isDirectory();
      if (isDirectory) {
        return [...files, ...getAllFiles(name, options)];
      } else {
        return /^_/.test(file) || !fileExtensionExp.test(file)
          ? [...files]
          : [...files, name];
      }
    }, [])
    .map(filePath => filePath.replace('.ts', ''));
};

module.exports = getAllFiles;
